@@ -2,6 +2,7 @@ from .dataset import collate_sequences, gen_amino_acid_vocab
 from .dataset import ProteinIterator, ProteinIterableDataset, ShuffledProteinIterableDataset
 from .dataset import ProteinDataset
 from .split import group_train_val_test_split, train_val_test_split
+from ..utils.imports import try_import_pytorch
 
 __all__ = ['collate_sequences',
            'gen_amino_acid_vocab',
@@ -12,3 +13,5 @@ __all__ = ['collate_sequences',
            'ProteinIterableDataset',
            'ShuffledProteinIterableDataset',
            ]
+
+try_import_pytorch()
