@@ -17,13 +17,15 @@ import warnings
 import numpy as np
 import pandas as pd
 from sklearn.preprocessing import LabelEncoder
-import torch
-from torch.utils.data import Dataset, IterableDataset
-from torch.utils.data.dataloader import default_collate
 from Bio.SeqRecord import SeqRecord
 
 from ..utils import get_logger, SynchronizedCounter
 from ..utils import EXTENDED_IUPAC_PROTEIN_ALPHABET, parse, SeqIO
+from ..utils import try_import_pytorch
+
+torch = try_import_pytorch()
+from torch.utils.data import Dataset, IterableDataset  # noqa
+from torch.utils.data.dataloader import default_collate  # noqa
 
 __all__ = ['collate_sequences',
            'gen_amino_acid_vocab',
@@ -68,7 +70,7 @@ def collate_sequences(batch: Union[List[sequence_tuple], sequence_tuple],
     min_length : int, optional
         Zero-pad sequences to at least ``min_length``.
         By default, this is set to 36, which is the largest kernel size in the
-        default DeepNOG/DeepEncoding architecture.
+        default DeepNOG architecture.
     random_padding : bool, optional
         Zero pad sequences by prepending and appending zeros. The fraction
         is determined randomly. This may counter detrimental effects, when
@@ -97,7 +99,7 @@ def collate_sequences(batch: Union[List[sequence_tuple], sequence_tuple],
             max_len = sequence_len
 
     # Collate the sequences
-    sequences = np.zeros((n_data, max_len,), dtype=np.int)
+    sequences = np.zeros((n_data, max_len,), dtype=np.int32)
     for i, seq in enumerate(batch):
         sequence = np.array(seq.encoded)
         # If selected, choose randomly, where to insert zeros
@@ -121,7 +123,7 @@ def collate_sequences(batch: Union[List[sequence_tuple], sequence_tuple],
 
     # Collate the labels
     try:
-        labels = np.array([b.label for b in batch], dtype=np.int)
+        labels = np.array([b.label for b in batch], dtype=np.int32)
         labels = default_collate(labels)
     except (AttributeError, TypeError):
         labels = None
@@ -529,7 +531,7 @@ class ProteinDataset(Dataset):
                                           compression='infer',
                                           dtype=str,
                                           )
-            except ValueError:
+            except (ValueError, TypeError):
                 pass
             if not isinstance(self.labels, pd.DataFrame):
                 raise ValueError('Invalid labels, must be .csv file or DataFrame')
