@@ -25,14 +25,15 @@ import warnings
 import numpy as np
 from tqdm.auto import tqdm
 
-import torch
-from torch.optim import Adam, lr_scheduler
-from torch.utils.data import DataLoader
-from torch.utils.tensorboard import SummaryWriter
-
 from ..data import ProteinDataset, ProteinIterableDataset, ShuffledProteinIterableDataset
 from ..data import collate_sequences
 from ..utils import count_parameters, get_config, get_logger, load_nn, set_device
+from ..utils import try_import_pytorch
+
+torch = try_import_pytorch()
+from torch.optim import Adam, lr_scheduler  # noqa
+from torch.utils.data import DataLoader  # noqa
+from torch.utils.tensorboard import SummaryWriter  # noqa
 
 __all__ = ['fit',
            ]
@@ -461,7 +462,7 @@ def fit(architecture, module, cls,
             logger.info(f'Using iterable dataset with shuffle buffer, '
                         f'and buffer size = {buffer_size}.')
         else:
-            dataset['train'] = ProteinIterableDataset(file=validation_sequences,
+            dataset['train'] = ProteinIterableDataset(file=training_sequences,
                                                       labels_file=training_labels)
             logger.info('Using iterable dataset without shuffling.')
         dataset['val'] = ProteinIterableDataset(file=validation_sequences,
