@@ -1,5 +1,6 @@
 from .bio import EXTENDED_IUPAC_PROTEIN_ALPHABET, SeqIO, parse
 from .config import get_config
+from .imports import try_import_pytorch
 from .io_utils import create_df, get_data_home, get_weights_path
 from .logger import get_logger
 from .sync import SynchronizedCounter
@@ -17,4 +18,5 @@ __all__ = ['count_parameters',
            'SeqIO',
            'set_device',
            'SynchronizedCounter',
+           'try_import_pytorch',
            ]
